@@ -1,7 +1,7 @@
 """This example shows how you can very easily flip a plot horizontally if you
 need, using Matplotlib's ax.set_xlim() method."""
 
-from dna_features_viewer import BiopythonTranslator, load_record
+from dna_features_viewer import BiopythonTranslator
 
 ax = BiopythonTranslator.quick_class_plot("example_sequence.gb")
 x1, x2 = ax.get_xlim()
